@@ -10,7 +10,7 @@ use DBI;
 use List::Util qw(first);
 
 
-our $VERSION = '0.7';
+our $VERSION = '1.0';
 
 
 =head1 NAME
@@ -19,6 +19,9 @@ Net::Google::SafeBrowsing2::DBI - Base class for all DBI-based back-end storage
 
 =head1 SYNOPSIS
 
+Net::Google::SafeBrowsing2::DBI cannot be used directly. Instead, use a class inheriting Net::Google::SafeBrowsing2::DBI, like L<Net::Google::SafeBrowsing2::MySQL>.
+
+
   use Net::Google::SafeBrowsing2::MySQL;
 
   my $storage = Net::Google::SafeBrowsing2::MySQL->new(host => '127.0.0.1', database => 'GoogleSafeBrowsingv2');
@@ -36,6 +39,8 @@ This is a base implementation of L<Net::Google::SafeBrowsing2::Storage> using DB
 
 =over 4
 
+=back
+
 =head2 new()
 
 This method should be overwritten.
@@ -48,8 +53,6 @@ Arguments
 
 Optional. Set to 1 to keep old information (such as expiring full hashes) in the database. 0 (delete) by default.
 
-=back
-
 
 =back
 
@@ -77,6 +80,8 @@ sub new {
 
 See L<Net::Google::SafeBrowsing2::Storage> for a complete list of public functions.
 
+=back
+
 =head2 close()
 
 Cleanup old full hashes, and close the connection to the database.
@@ -240,10 +245,6 @@ sub export {
 	CORE::close(EXPORT);
 }
 
-=back
-
-=cut
-
 sub init {
 	my ($self, %args) = @_;
 
@@ -446,8 +447,8 @@ sub add_chunks_s {
 	}
 
 	if (scalar @$chunks == 0) { # keep empty chunks
-		$del->execute( '', '', '', $chunknum, $list );
-		$add->execute( '', '', '', $chunknum, $list );
+		$del->execute( '', '', $chunknum, '', $list );
+		$add->execute( '', '', $chunknum, '', $list );
 	}
 }
 
@@ -767,6 +768,10 @@ sub create_range {
 
 =over 4
 
+=item 0.7.1
+
+Fix for empty sub chunks.
+
 =item 0.7
 
 New C<export()> function.
@@ -823,4 +828,4 @@ at your option, any later version of Perl 5 you may have available.
 
 =cut
 
-1;
\ No newline at end of file
+1;
